@@ -1,3 +1,20 @@
+/******************************************************************************/
+/* virtual-touchpad                                                           */
+/* Copyright (C) 2013-2014 Moses Palmér                                       */
+/*                                                                            */
+/* This program is free software: you can redistribute it and/or modify it    */
+/* under the terms of the GNU General Public License as published by the Free */
+/* Software Foundation, either version 3 of the License, or (at your option)  */
+/* any later version.                                                         */
+/*                                                                            */
+/* This program is distributed in the hope that it will be useful, but        */
+/* WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY */
+/* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License    */
+/* for more details.                                                          */
+/*                                                                            */
+/* You should have received a copy of the GNU General Public License along    */
+/* with this program. If not, see <http://www.gnu.org/licenses/>.             */
+/******************************************************************************/
 exports.checks = (function() {
     var module = {
         failures: []};
@@ -26,7 +43,7 @@ exports.checks = (function() {
         module.failures.push("TouchEvents");
     }
     else {
-        if (typeof(TouchList.prototype.identifiedTouch) == "undefined") {
+        if (typeof(TouchList.prototype.identifiedTouch) === "undefined") {
             TouchList.prototype.identifiedTouch = function(identifier) {
                 for (var i = 0; i < this.length; i++) {
                     if (this[i].identifier === identifier) {
@@ -67,6 +84,10 @@ exports.checks = (function() {
             module.failures.push("Fullscreen");
         }
     }
+    else {
+        document.FULLSCREENCHANGE_EVENT_NAME = "fullscreenchange";
+        document.FULLSCREEN_ELEMENT_NAME = "FullscreenElement";
+    }
 
     // Check for Web Storage
     if (typeof("Storage") == "undefined") {
@@ -75,4 +96,3 @@ exports.checks = (function() {
 
     return module;
 })();
-
